/* jshint globalstrict:true */
'use strict';

const OVERLAY_TEMPLATES_BASE_COLORS_CONTAINER_ID = 'locrmaps-overlay-templates-base-colors';

/**
 * @param {HTMLSelectElement} select
 */
function trySettingOverlayTemplateBaseColor(select) {
    if (!(select.options[select.selectedIndex] instanceof HTMLOptionElement)) {
        return;
    }
    if (!wp || !wp.hooks) {
        window.console.warn('trySettingOverlayTemplateBaseColor: wp.hooks is not available');
        return;
    }

    const selectioOption = select.options[select.selectedIndex];
    wp.hooks.doAction( 'locrMAPSForWooCommerceSetOverlayTemplateBaseColor', { value: selectioOption.value || 'white' } );
}

document.addEventListener('DOMContentLoaded', function() {
    const overlayTemplatesBaseColorsElement = document.getElementById(OVERLAY_TEMPLATES_BASE_COLORS_CONTAINER_ID);
    if (overlayTemplatesBaseColorsElement instanceof HTMLSelectElement) {
        overlayTemplatesBaseColorsElement.addEventListener('change', function(event) {
            if (!(event.target instanceof HTMLSelectElement)) {
                return;
            }

            trySettingOverlayTemplateBaseColor(event.target);
        });

        if (overlayTemplatesBaseColorsElement.value) {
            trySettingOverlayTemplateBaseColor(overlayTemplatesBaseColorsElement);

            wp?.hooks?.addAction(
                'locrMAPSInitialized',
                'locr/locrmaps',
                () => trySettingOverlayTemplateBaseColor(overlayTemplatesBaseColorsElement)
            );
        }
    }
});
